/**
 * CNavCustomBar - 自定义导航条
 * @author chensi
 */

<template>
    <view
        class="c-nav-custom-bar"
        :style="{height:navBarHeight + 'px',paddingTop:statusBarHeight + 'px',boxSizing:'border-box'}"
    >
        <view
            class="c-nav-icon"
            :style="{height:(navBarHeight - statusBarHeight) + 'px'}"
        >
            <view
                v-if="!isNeedBackIcon"
                class="c-nav-menu-icon"
            >
                <slot name="icon"></slot>
            </view>
            <view
                v-if="isNeedBackIcon"
                class="c-nav-back-icon"
                @tap="evt => onBack()"
            >
                <AtIcon
                    value='chevron-left'
                    size='26'
                    color='#000'
                ></AtIcon>
            </view>
        </view>
        <view class="c-nav-title">
            {{ title }}
        </view>
    </view>
</template>

<script>
import Taro from '@tarojs/taro';
import { AtIcon } from 'taro-ui-vue';
import './cNavCustomBar.scss';

export default {
    name: 'CNavCustomBar',
    components: {
        AtIcon,
    },
    props: {
        isNeedBackIcon: {
            type: Boolean,
            default: false,
        },
        title: {
            type: String,
            default: '',
        },
    },
    computed: {},
    data() {
        return {
            navBarHeight: 0,
            statusBarHeight: 0,
        };
    },
    mounted() {
        this.getNavBarHeight();
    },
    methods: {
        getNavBarHeight() {
            //获取胶囊对象
            let menuButtonObject = Taro.getMenuButtonBoundingClientRect();
            // 获取设备系统对象
            let sysInfo = wx.getSystemInfoSync();
            // 获取状态栏高度
            let statusBarHeight = sysInfo.statusBarHeight;
            // 获取胶囊高度
            let menuButtonHeight = menuButtonObject.height;
            // 获取胶囊距离顶部的高度
            let distanceTop = menuButtonObject.top;
            //计算nav导航栏的高度
            let navBarHeight =
                statusBarHeight + menuButtonHeight + (distanceTop - statusBarHeight) * 2;
            this.navBarHeight = navBarHeight;
            this.statusBarHeight = statusBarHeight;
        },

        onBack() {
            Taro.navigateBack({
                delta: 1,
            });
        },

        $getStatusBarHeight() {
            return this.statusBarHeight;
        },

        //  使用自定义导航时，需要在主页显示的设置padding的值，此值是导航栏的高度，本导航已经使用固定定位为头部
        $getNavBarHeight() {
            return this.navBarHeight;
        },
    },
};
</script>
